@@ -1,4 +1,4 @@
-// Copyright (c) 2021-2022, Sylabs Inc. All rights reserved.
+// Copyright (c) 2021-2023, Sylabs Inc. All rights reserved.
 // This software is licensed under a 3-clause BSD license. Please consult the
 // LICENSE file distributed with the sources of this project regarding your
 // rights to use or distribute this software.
@@ -20,18 +20,13 @@ func Test_command_getDump(t *testing.T) {
 		{
 			name: "One",
 			id:   "1",
-			path: filepath.Join(corpus, "one-group-signed.sif"),
+			path: filepath.Join(corpus, "one-group.sif"),
 		},
 		{
 			name: "Two",
-			path: filepath.Join(corpus, "one-group-signed.sif"),
+			path: filepath.Join(corpus, "one-group.sif"),
 			id:   "2",
 		},
-		{
-			name: "Three",
-			path: filepath.Join(corpus, "one-group-signed.sif"),
-			id:   "3",
-		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
